==> haskell-cprng-aes-0.6.1-66-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cprng-aes.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cprng-aes
version: 0.6.1
id: cprng-aes-0.6.1-EzIBSReTAQ41PPR31075r1
key: cprng-aes-0.6.1-EzIBSReTAQ41PPR31075r1
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-cprng-aes
synopsis: Crypto Pseudo Random Number Generator using AES in counter mode.
description:
    Simple crypto pseudo-random-number-generator with really good randomness property.
    .
    Using ent, a randomness property maker on one 1Mb sample:
    Entropy = 7.999837 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 237.02
    Arithmetic mean value of data bytes is 127.3422 (127.5 = random)
    Monte Carlo value for Pi is 3.143589568 (error 0.06 percent)
    .
    Compared to urandom with the same sampling:
    Entropy = 7.999831 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 246.63
    Arithmetic mean value of data bytes is 127.6347 (127.5 = random).
    Monte Carlo value for Pi is 3.132465868 (error 0.29 percent).
category: Cryptography
abi: 645cf2adcc6e9c704c440fc61aaf4bbb
exposed: True
exposed-modules:
    Crypto.Random.AESCtr
hidden-modules: Crypto.Random.AESCtr.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/cprng-aes-0.6.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/cprng-aes-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-cprng-aes
hs-libraries: HScprng-aes-0.6.1-EzIBSReTAQ41PPR31075r1
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY
    crypto-random-0.0.9-FWjny2ACuEk74S93d3lIOm
    cipher-aes-0.2.11-FRyhJ05rCDW18ACC9UuHoq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY=cdb4e7359967ea10cd00ae1d3fab6945
             crypto-random-0.0.9-FWjny2ACuEk74S93d3lIOm=ab3b0f3d326ec2e98980f9a72390f112
             cipher-aes-0.2.11-FRyhJ05rCDW18ACC9UuHoq=b4bd93549f16bf0162ef317d406a1257
haddock-interfaces: /usr/share/doc/haskell-cprng-aes/html/cprng-aes.haddock
haddock-html: /usr/share/doc/haskell-cprng-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cprng-aes-0.6.1-75-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cprng-aes.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cprng-aes
version: 0.6.1
id: cprng-aes-0.6.1-KIQ84vYjRh74JaV0PdAaUp
key: cprng-aes-0.6.1-KIQ84vYjRh74JaV0PdAaUp
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-cprng-aes
synopsis: Crypto Pseudo Random Number Generator using AES in counter mode.
description:
    Simple crypto pseudo-random-number-generator with really good randomness property.
    .
    Using ent, a randomness property maker on one 1Mb sample:
    Entropy = 7.999837 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 237.02
    Arithmetic mean value of data bytes is 127.3422 (127.5 = random)
    Monte Carlo value for Pi is 3.143589568 (error 0.06 percent)
    .
    Compared to urandom with the same sampling:
    Entropy = 7.999831 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 246.63
    Arithmetic mean value of data bytes is 127.6347 (127.5 = random).
    Monte Carlo value for Pi is 3.132465868 (error 0.29 percent).
category: Cryptography
abi: 05de6609e832ded3b7cd499afac57ce8
exposed: True
exposed-modules:
    Crypto.Random.AESCtr
hidden-modules: Crypto.Random.AESCtr.Internal
import-dirs: /usr/lib/ghc-8.6.1/site-local/cprng-aes-0.6.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/cprng-aes-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-cprng-aes
hs-libraries: HScprng-aes-0.6.1-KIQ84vYjRh74JaV0PdAaUp
depends:
    base-4.12.0.0 byteable-0.1.1-9guyEXUUK503mzSnI32g2S
    bytestring-0.10.8.2 cipher-aes-0.2.11-3NOoNeD5fhf7KVeRBQcKrW
    crypto-random-0.0.9-ImEu1YHQEagDk1EizvA7Wq
haddock-interfaces: /usr/share/doc/haskell-cprng-aes/html/cprng-aes.haddock
haddock-html: /usr/share/doc/haskell-cprng-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
